@@ -1,6 +1,8 @@
 /**************************************************
 OpengateM - a MAC address authentication system
- module for checking ttl (or hlim in v6) to detect router
+ module for checking TTL(TimeToLive) (or hlim in ipv6) to detect router
+ defaut TTL has some fixed value (depending OS).
+ and it is decrement at passing the router/NAT.
 
 Copyright (C) 2011 Opengate Project Team
 Written by Yoshiaki Watanabe
